summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/htmlexport
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:03 -0600
commit3ed629ae12e33ac8a9c744e79135a4100d16b036 (patch)
tree4517ed969da6be83410ef6cea3589864f6cab6a4 /kipi-plugins/htmlexport
parent650c190e4a29a2a17fd46b32ce78b956b9816215 (diff)
downloadkipi-plugins-3ed629ae12e33ac8a9c744e79135a4100d16b036.tar.gz
kipi-plugins-3ed629ae12e33ac8a9c744e79135a4100d16b036.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 650c190e4a29a2a17fd46b32ce78b956b9816215.
Diffstat (limited to 'kipi-plugins/htmlexport')
-rw-r--r--kipi-plugins/htmlexport/generator.cpp26
-rw-r--r--kipi-plugins/htmlexport/imagesettingspage.ui22
-rw-r--r--kipi-plugins/htmlexport/listthemeparameter.cpp4
-rw-r--r--kipi-plugins/htmlexport/outputpage.ui4
-rw-r--r--kipi-plugins/htmlexport/theme.cpp2
-rw-r--r--kipi-plugins/htmlexport/themeparameterspage.ui6
-rw-r--r--kipi-plugins/htmlexport/wizard.cpp34
7 files changed, 49 insertions, 49 deletions
diff --git a/kipi-plugins/htmlexport/generator.cpp b/kipi-plugins/htmlexport/generator.cpp
index d1bbe1c..2e52161 100644
--- a/kipi-plugins/htmlexport/generator.cpp
+++ b/kipi-plugins/htmlexport/generator.cpp
@@ -172,7 +172,7 @@ struct Generator::Private {
bool init() {
mTheme=Theme::findByInternalName(mInfo->theme());
if (!mTheme) {
- logError( i18n("Could not find theme in '%1'").arg(mInfo->theme()) );
+ logError( i18n("Could not find theme in '%1'").tqarg(mInfo->theme()) );
return false;
}
return true;
@@ -200,11 +200,11 @@ struct Generator::Private {
bool writeDataToFile(const TQByteArray& data, const TQString& destPath) {
TQFile destFile(destPath);
if (!destFile.open(IO_WriteOnly)) {
- logWarning(i18n("Could not open file '%1' for writing").arg(destPath));
+ logWarning(i18n("Could not open file '%1' for writing").tqarg(destPath));
return false;
}
if (destFile.writeBlock(data) != (TQ_LONG)data.size()) {
- logWarning(i18n("Could not save image to file '%1'").arg(destPath));
+ logWarning(i18n("Could not save image to file '%1'").tqarg(destPath));
return false;
}
return true;
@@ -233,13 +233,13 @@ struct Generator::Private {
TQString path=imageURL.path();
TQFile imageFile(path);
if (!imageFile.open(IO_ReadOnly)) {
- logWarning(i18n("Could not read image '%1'").arg(path));
+ logWarning(i18n("Could not read image '%1'").tqarg(path));
return;
}
TQString imageFormat = TQImageIO::imageFormat(TQT_TQIODEVICE(&imageFile));
if (imageFormat.isEmpty()) {
- logWarning(i18n("Format of image '%1' is unknown").arg(path));
+ logWarning(i18n("Format of image '%1' is unknown").tqarg(path));
return;
}
imageFile.close();
@@ -248,7 +248,7 @@ struct Generator::Private {
TQByteArray imageData = imageFile.readAll();
TQImage originalImage;
if (!originalImage.loadFromData(imageData) ) {
- logWarning(i18n("Error loading image '%1'").arg(path));
+ logWarning(i18n("Error loading image '%1'").tqarg(path));
return;
}
@@ -284,7 +284,7 @@ struct Generator::Private {
fullFileName = baseFileName + "." + mInfo->fullFormatString().lower();
TQString destPath = destDir + "/" + fullFileName;
if (!fullImage.save(destPath, mInfo->fullFormatString().ascii(), mInfo->fullQuality())) {
- logWarning(i18n("Could not save image '%1' to '%2'").arg(path).arg(destPath));
+ logWarning(i18n("Could not save image '%1' to '%2'").tqarg(path).tqarg(destPath));
return;
}
}
@@ -302,7 +302,7 @@ struct Generator::Private {
TQString thumbnailFileName = "thumb_" + baseFileName + "." + mInfo->thumbnailFormatString().lower();
TQString destPath = destDir + "/" + thumbnailFileName;
if (!thumbnail.save(destPath, mInfo->thumbnailFormatString().ascii(), mInfo->thumbnailQuality())) {
- logWarning(i18n("Could not save thumbnail for image '%1' to '%2'").arg(path).arg(destPath));
+ logWarning(i18n("Could not save thumbnail for image '%1' to '%2'").tqarg(path).tqarg(destPath));
return;
}
@@ -337,7 +337,7 @@ struct Generator::Private {
TQValueList<KIPI::ImageCollection>::Iterator collectionEnd=mInfo->mCollectionList.end();
for (; collectionIt!=collectionEnd; ++collectionIt) {
KIPI::ImageCollection collection=*collectionIt;
- logInfo( i18n("Generating files for \"%1\"").arg(collection.name()) );
+ logInfo( i18n("Generating files for \"%1\"").tqarg(collection.name()) );
TQString collectionFileName = webifyFileName(collection.name());
TQString destDir = baseDestDir + "/" + collectionFileName;
@@ -406,13 +406,13 @@ struct Generator::Private {
CWrapper<xsltStylesheetPtr, xsltFreeStylesheet> xslt= xsltParseStylesheetFile( (const xmlChar*) xsltFileName.local8Bit().data() );
if (!xslt) {
- logError(i18n("Could not load XSL file '%1'").arg(xsltFileName));
+ logError(i18n("Could not load XSL file '%1'").tqarg(xsltFileName));
return false;
}
CWrapper<xmlDocPtr, xmlFreeDoc> xmlGallery=xmlParseFile( mXMLFileName.local8Bit().data() );
if (!xmlGallery) {
- logError(i18n("Could not load XML file '%1'").arg(mXMLFileName));
+ logError(i18n("Could not load XML file '%1'").tqarg(mXMLFileName));
return false;
}
@@ -451,7 +451,7 @@ struct Generator::Private {
TQString destFileName=mInfo->destKURL().path() + "/index.html";
FILE* file=fopen(destFileName.local8Bit().data(), "w");
if (!file) {
- logError(i18n("Could not open '%1' for writing").arg(destFileName));
+ logError(i18n("Could not open '%1' for writing").tqarg(destFileName));
return false;
}
xsltSaveResultToFile(file, xmlOutput, xslt);
@@ -469,7 +469,7 @@ struct Generator::Private {
TQString part = *it;
if (!dir.exists(part)) {
if (!dir.mkdir(part)) {
- logError(i18n("Could not create folder '%1' in '%2'").arg(part).arg(dir.absPath()));
+ logError(i18n("Could not create folder '%1' in '%2'").tqarg(part).tqarg(dir.absPath()));
return false;
}
}
diff --git a/kipi-plugins/htmlexport/imagesettingspage.ui b/kipi-plugins/htmlexport/imagesettingspage.ui
index 596076e..d200786 100644
--- a/kipi-plugins/htmlexport/imagesettingspage.ui
+++ b/kipi-plugins/htmlexport/imagesettingspage.ui
@@ -45,7 +45,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>58</width>
<height>20</height>
@@ -62,7 +62,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -79,7 +79,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>104</height>
@@ -109,7 +109,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -126,7 +126,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -244,7 +244,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -288,7 +288,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -305,7 +305,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>19</height>
@@ -332,7 +332,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -341,7 +341,7 @@
</spacer>
<widget class="TQLayoutWidget" row="4" column="1" rowspan="1" colspan="2">
<property name="name">
- <cstring>layout13</cstring>
+ <cstring>tqlayout13</cstring>
</property>
<grid>
<property name="name">
@@ -401,7 +401,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kipi-plugins/htmlexport/listthemeparameter.cpp b/kipi-plugins/htmlexport/listthemeparameter.cpp
index e2bb23e..8bae470 100644
--- a/kipi-plugins/htmlexport/listthemeparameter.cpp
+++ b/kipi-plugins/htmlexport/listthemeparameter.cpp
@@ -49,8 +49,8 @@ void ListThemeParameter::init(const TQCString& internalName, const KConfigBase*
AbstractThemeParameter::init(internalName, configFile);
for (int pos=0;; ++pos) {
- TQString valueKey = TQString("%1%2").arg(ITEM_VALUE_KEY).arg(pos);
- TQString captionKey = TQString("%1%2").arg(ITEM_CAPTION_KEY).arg(pos);
+ TQString valueKey = TQString("%1%2").tqarg(ITEM_VALUE_KEY).tqarg(pos);
+ TQString captionKey = TQString("%1%2").tqarg(ITEM_CAPTION_KEY).tqarg(pos);
if (!configFile->hasKey(valueKey) || !configFile->hasKey(captionKey)) {
break;
}
diff --git a/kipi-plugins/htmlexport/outputpage.ui b/kipi-plugins/htmlexport/outputpage.ui
index aa7e3f4..6ece24d 100644
--- a/kipi-plugins/htmlexport/outputpage.ui
+++ b/kipi-plugins/htmlexport/outputpage.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<hbox>
<property name="name">
@@ -63,7 +63,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>51</height>
diff --git a/kipi-plugins/htmlexport/theme.cpp b/kipi-plugins/htmlexport/theme.cpp
index 74aafae..02531a8 100644
--- a/kipi-plugins/htmlexport/theme.cpp
+++ b/kipi-plugins/htmlexport/theme.cpp
@@ -24,7 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
// TQt
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
// KDE
#include <kdebug.h>
diff --git a/kipi-plugins/htmlexport/themeparameterspage.ui b/kipi-plugins/htmlexport/themeparameterspage.ui
index 4fd5a21..2d05fda 100644
--- a/kipi-plugins/htmlexport/themeparameterspage.ui
+++ b/kipi-plugins/htmlexport/themeparameterspage.ui
@@ -37,7 +37,7 @@
<property name="text">
<string>In this page, you can change some theme parameters. Depending on the theme, different parameters are available.</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
@@ -51,7 +51,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -79,7 +79,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kipi-plugins/htmlexport/wizard.cpp b/kipi-plugins/htmlexport/wizard.cpp
index c64fb0a..acc7f6e 100644
--- a/kipi-plugins/htmlexport/wizard.cpp
+++ b/kipi-plugins/htmlexport/wizard.cpp
@@ -27,7 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
#include <tqdir.h>
#include <tqfileinfo.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqobjectlist.h>
#include <tqpainter.h>
#include <tqspinbox.h>
@@ -102,7 +102,7 @@ struct Wizard::Private {
void fillThemeParametersPage(Theme::Ptr theme) {
// Delete any previous widgets
TQFrame* content = mThemeParametersPage->content;
- if (content->layout()) {
+ if (content->tqlayout()) {
// Setting recursiveSearch to false is very important, if we don't
// we will end up deleting subwidgets of our child widgets
TQObjectList* list = content->queryList(TQWIDGET_OBJECT_NAME_STRING, 0 /*objName*/,
@@ -112,14 +112,14 @@ struct Wizard::Private {
delete it.current();
}
- delete content->layout();
+ delete content->tqlayout();
}
mThemeParameterWidgetFromName.clear();
// Create layout. We need to recreate it everytime, to get rid of
// spacers
- TQGridLayout* layout = new TQGridLayout(content, 0, 3);
- layout->setSpacing(KDialog::spacingHint());
+ TQGridLayout* tqlayout = new TQGridLayout(content, 0, 3);
+ tqlayout->setSpacing(KDialog::spacingHint());
// Create widgets
Theme::ParameterList parameterList = theme->parameterList();
@@ -136,23 +136,23 @@ struct Wizard::Private {
themeParameter->defaultValue());
TQString name = themeParameter->name();
- name = i18n("'%1' is a label for a theme parameter", "%1:").arg(name);
+ name = i18n("'%1' is a label for a theme parameter", "%1:").tqarg(name);
TQLabel* label = new TQLabel(name, content);
TQWidget* widget = themeParameter->createWidget(content, value);
label->setBuddy(widget);
- int row = layout->numRows();
- layout->addWidget(label, row, 0);
+ int row = tqlayout->numRows();
+ tqlayout->addWidget(label, row, 0);
- if (widget->sizePolicy().expanding() & TQSizePolicy::Horizontally) {
+ if (widget->tqsizePolicy().expanding() & TQSizePolicy::Horizontally) {
// Widget wants full width
- layout->addMultiCellWidget(widget, row, row, 1, 2);
+ tqlayout->addMultiCellWidget(widget, row, row, 1, 2);
} else {
// Widget doesn't like to be stretched, add a spacer next to it
- layout->addWidget(widget, row, 1);
+ tqlayout->addWidget(widget, row, 1);
TQSpacerItem* spacer = new TQSpacerItem(1, 1, TQSizePolicy::Expanding, TQSizePolicy::Minimum);
- layout->addItem(spacer, row, 2);
+ tqlayout->addItem(spacer, row, 2);
}
mThemeParameterWidgetFromName[internalName] = widget;
@@ -161,7 +161,7 @@ struct Wizard::Private {
// Add spacer at the end, so that widgets aren't spread on the whole
// parent height
TQSpacerItem* spacer = new TQSpacerItem(1, 1, TQSizePolicy::Minimum, TQSizePolicy::Expanding);
- layout->addItem(spacer, layout->numRows(), 0);
+ tqlayout->addItem(spacer, tqlayout->numRows(), 0);
}
};
@@ -242,12 +242,12 @@ void Wizard::slotThemeSelectionChanged() {
TQString url=theme->authorUrl();
TQString author=theme->authorName();
if (!url.isEmpty()) {
- author=TQString("<a href='%1'>%2</a>").arg(url).arg(author);
+ author=TQString("<a href='%1'>%2</a>").tqarg(url).tqarg(author);
}
TQString txt=
- TQString("<b>%1</b><br><br>%2<br><br>").arg(theme->name(), theme->comment())
- + i18n("Author: %1").arg(author);
+ TQString("<b>%1</b><br><br>%2<br><br>").tqarg(theme->name(), theme->comment())
+ + i18n("Author: %1").tqarg(author);
browser->setText(txt);
setNextEnabled(d->mThemePage, true);
@@ -112,14 +112,14 @@ struct Wizard::Private {
}
mThemeParameterWidgetFromName.clear();
- // Create layout. We need to recreate it everytime, to get rid of
+ // Create tqlayout. We need to recreate it everytime, to get rid of
// spacers